Select the number of tensor synergies by a VAF threshold
Source:R/emg-tensor.R
muscleSynergyTensorOrder.RdFits non-negative PARAFAC for increasing rank and returns the smallest number
of synergies whose reconstruction VAF reaches vaf_threshold.
Arguments
- tensor
A non-negative
muscle x time x trialarray.- max_synergies
Largest rank to try (default 6).
- vaf_threshold
VAF target (default 0.90).
- ...
Passed to
muscleSynergyTensor().