Retrieves the SENIAM electrode/muscle metadata previously attached with
setEMGElectrode().
Value
A data.frame with one row per channel and columns channel,
muscle, placement, orientation, ied_mm,
reference and side (NA where unset).
Examples
pe <- PhysioExperiment(assays = list(raw = matrix(rnorm(100), ncol = 1)),
samplingRate = 1000)
pe <- setEMGElectrode(pe, muscle = "Tibialis anterior")
getEMGElectrode(pe)
#> channel muscle
#> 1 1 Tibialis anterior
#> placement
#> 1 At 1/3 on the line between the tip of the fibula and the tip of the medial malleolus
#> orientation ied_mm reference side
#> 1 Along the tibia 20 <NA> <NA>